@@ -50,7 +50,7 @@ private:
  * @author Robby Stephenson
  */
 class CollectionFieldsDialog : public KDialogBase {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
