@@ -46,21 +46,21 @@
 #include "googlescholarfetcher.h"
 #include "discogsfetcher.h"
 
-#include <kglobal.h>
-#include <kconfig.h>
-#include <klocale.h>
+#include <tdeglobal.h>
+#include <tdeconfig.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
 #include <kmimetype.h>
 #include <kstandarddirs.h>
 #include <dcopref.h>
-#include <ktempfile.h>
-#include <kio/netaccess.h>
+#include <tdetempfile.h>
+#include <tdeio/netaccess.h>
 
 #include <tqfileinfo.h>
 #include <tqdir.h>
 
 #define LOAD_ICON(name, group, size) \
-  KGlobal::iconLoader()->loadIcon(name, static_cast<KIcon::Group>(group), size_)
+  TDEGlobal::iconLoader()->loadIcon(name, static_cast<TDEIcon::Group>(group), size_)
 
 using Tellico::Fetch::Manager;
 Manager* Manager::s_self = 0;
@@ -93,9 +93,9 @@ void Manager::loadFetchers() {
   m_fetchers.clear();
   m_configMap.clear();
 
-  KConfig* config = KGlobal::config();
+  TDEConfig* config = TDEGlobal::config();
   if(config->hasGroup(TQString::fromLatin1("Data Sources"))) {
-    KConfigGroup configGroup(config, TQString::fromLatin1("Data Sources"));
+    TDEConfigGroup configGroup(config, TQString::fromLatin1("Data Sources"));
     int nSources = configGroup.readNumEntry("Sources Count", 0);
     for(int i = 0; i < nSources; ++i) {
       TQString group = TQString::fromLatin1("Data Source %1").arg(i);
@@ -130,7 +130,7 @@ Tellico::Fetch::KeyMap Manager::keyMap(const TQString& source_) const {
   }
 
   // assume there's only one fetcher match
-  KSharedPtr<const Fetcher> f = 0;
+  TDESharedPtr<const Fetcher> f = 0;
   for(FetcherVec::ConstIterator it = m_fetchers.constBegin(); it != m_fetchers.constEnd(); ++it) {
     if(source_ == it->source()) {
       f = it.data();
@@ -163,10 +163,10 @@ void Manager::startSearch(const TQString& source_, FetchKey key_, const TQString
   for(FetcherVec::Iterator it = m_fetchers.begin(); it != m_fetchers.end(); ++it, ++i) {
     if(source_ == it->source()) {
       ++m_count; // Fetcher::search() might emit done(), so increment before calling search()
-      connect(it.data(), TQT_SIGNAL(signalResultFound(Tellico::Fetch::SearchResult*)),
-              TQT_SIGNAL(signalResultFound(Tellico::Fetch::SearchResult*)));
-      connect(it.data(), TQT_SIGNAL(signalDone(Tellico::Fetch::Fetcher::Ptr)),
-              TQT_SLOT(slotFetcherDone(Tellico::Fetch::Fetcher::Ptr)));
+      connect(it.data(), TQ_SIGNAL(signalResultFound(Tellico::Fetch::SearchResult*)),
+              TQ_SIGNAL(signalResultFound(Tellico::Fetch::SearchResult*)));
+      connect(it.data(), TQ_SIGNAL(signalDone(Tellico::Fetch::Fetcher::Ptr)),
+              TQ_SLOT(slotFetcherDone(Tellico::Fetch::Fetcher::Ptr)));
       it->search(key_, value_);
       m_currentFetcherIndex = i;
       break;
@@ -183,10 +183,10 @@ void Manager::continueSearch() {
   Fetcher::Ptr f = m_fetchers[m_currentFetcherIndex];
   if(f && f->hasMoreResults()) {
     ++m_count;
-    connect(f, TQT_SIGNAL(signalResultFound(Tellico::Fetch::SearchResult*)),
-            TQT_SIGNAL(signalResultFound(Tellico::Fetch::SearchResult*)));
-    connect(f, TQT_SIGNAL(signalDone(Tellico::Fetch::Fetcher::Ptr)),
-            TQT_SLOT(slotFetcherDone(Tellico::Fetch::Fetcher::Ptr)));
+    connect(f, TQ_SIGNAL(signalResultFound(Tellico::Fetch::SearchResult*)),
+            TQ_SIGNAL(signalResultFound(Tellico::Fetch::SearchResult*)));
+    connect(f, TQ_SIGNAL(signalDone(Tellico::Fetch::Fetcher::Ptr)),
+            TQ_SLOT(slotFetcherDone(Tellico::Fetch::Fetcher::Ptr)));
     f->continueSearch();
   } else {
     emit signalDone();
@@ -235,13 +235,13 @@ bool Manager::canFetch() const {
   return false;
 }
 
-Tellico::Fetch::Fetcher::Ptr Manager::createFetcher(KConfig* config_, const TQString& group_) {
+Tellico::Fetch::Fetcher::Ptr Manager::createFetcher(TDEConfig* config_, const TQString& group_) {
   if(!config_->hasGroup(group_)) {
     myDebug() << "Manager::createFetcher() - no config group for " << group_ << endl;
     return 0;
   }
 
-  KConfigGroup config(config_, group_);
+  TDEConfigGroup config(config_, group_);
 
   int fetchType = config.readNumEntry("Type", Fetch::Unknown);
   if(fetchType == Fetch::Unknown) {
@@ -359,7 +359,7 @@ Tellico::Fetch::FetcherVec Manager::defaultFetchers() {
   vec.append(new GoogleScholarFetcher(this));
   vec.append(new DiscogsFetcher(this));
 // only add IBS if user includes italian
-  if(KGlobal::locale()->languagesTwoAlpha().contains(TQString::fromLatin1("it"))) {
+  if(TDEGlobal::locale()->languagesTwoAlpha().contains(TQString::fromLatin1("it"))) {
     vec.append(new IBSFetcher(this));
   }
   return vec;
@@ -371,12 +371,12 @@ Tellico::Fetch::FetcherVec Manager::createUpdateFetchers(int collType_) {
   }
 
   FetcherVec vec;
-  KConfigGroup config(KGlobal::config(), "Data Sources");
+  TDEConfigGroup config(TDEGlobal::config(), "Data Sources");
   int nSources = config.readNumEntry("Sources Count", 0);
   for(int i = 0; i < nSources; ++i) {
     TQString group = TQString::fromLatin1("Data Source %1").arg(i);
-    // needs the KConfig*
-    Fetcher::Ptr f = createFetcher(KGlobal::config(), group);
+    // needs the TDEConfig*
+    Fetcher::Ptr f = createFetcher(TDEGlobal::config(), group);
     if(f && f->canFetch(collType_) && f->canUpdate()) {
       vec.append(f);
     }
@@ -440,10 +440,10 @@ Tellico::Fetch::TypePairList Manager::typeList() {
   list.append(TypePair(DiscogsFetcher::defaultName(),      Discogs));
 
   // now find all the scripts distributed with tellico
-  TQStringList files = KGlobal::dirs()->findAllResources("appdata", TQString::fromLatin1("data-sources/*.spec"),
+  TQStringList files = TDEGlobal::dirs()->findAllResources("appdata", TQString::fromLatin1("data-sources/*.spec"),
                                                         false, true);
   for(TQStringList::Iterator it = files.begin(); it != files.end(); ++it) {
-    KConfig spec(*it, false, false);
+    TDEConfig spec(*it, false, false);
     TQString name = spec.readEntry("Name");
     if(name.isEmpty()) {
       myDebug() << "Fetch::Manager::typeList() - no Name for " << *it << endl;
@@ -499,10 +499,10 @@ Tellico::Fetch::ConfigWidget* Manager::configWidget(TQWidget* parent_, Type type
         from.setPath(m_scriptMap[name_]);
         to.setPath(tmpFile.name());
         // have to overwrite since KTempFile already created it
-        if(!KIO::NetAccess::file_copy(from, to, -1, true /*overwrite*/)) {
-          myDebug() << KIO::NetAccess::lastErrorString() << endl;
+        if(!TDEIO::NetAccess::file_copy(from, to, -1, true /*overwrite*/)) {
+          myDebug() << TDEIO::NetAccess::lastErrorString() << endl;
         }
-        KConfig spec(to.path(), false, false);
+        TDEConfig spec(to.path(), false, false);
         // pass actual location of spec file
         if(name_ == spec.readEntry("Name") && bundledScriptHasExecPath(m_scriptMap[name_], &spec)) {
           static_cast<ExecExternalFetcher::ConfigWidget*>(w)->readConfig(&spec);
@@ -634,7 +634,7 @@ TQPixmap Manager::fetcherIcon(Fetch::Type type_, int group_, int size_) {
     case Entrez:
       name = favIcon("http://www.ncbi.nlm.nih.gov"); break;
     case ExecExternal:
-      name = TQString::fromLatin1("exec"); break;
+      name = TQString::fromLatin1("application-x-executable"); break;
     case Yahoo:
       name = favIcon("http://yahoo.com"); break;
     case AnimeNfo:
@@ -677,7 +677,7 @@ TQString Manager::favIcon(const KURL& url_) {
   return KMimeType::iconForURL(url_);
 }
 
-bool Manager::bundledScriptHasExecPath(const TQString& specFile_, KConfig* config_) {
+bool Manager::bundledScriptHasExecPath(const TQString& specFile_, TDEConfig* config_) {
   // make sure ExecPath is set and executable
   // for the bundled scripts, either the exec name is not set, in which case it is the
   // name of the spec file, minus the .spec, or the exec is set, and is local to the dir
