@@ -41,7 +41,7 @@ namespace Tellico {
  * @author Robby Stephenson
  */
 class BibtexImporter : public Importer {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
